@@ -25,6 +25,7 @@ from marshmallow.exceptions import (
     FieldInstanceResolutionError,
 )
 from marshmallow.validate import Validator, Length
+from marshmallow.warnings import RemovedInMarshmallow4Warning
 
 __all__ = [
     "Field",
@@ -269,7 +270,7 @@ class Field(FieldABC):
             '`Field.fail` is deprecated. Use `raise self.make_error("{}", ...)` instead.'.format(
                 key
             ),
-            DeprecationWarning,
+            RemovedInMarshmallow4Warning,
         )
         raise self.make_error(key=key, **kwargs)
 
@@ -451,8 +452,7 @@ class Nested(Field):
         # No
         author = fields.Nested(UserSchema(), only=('id', 'name'))
 
-    :param nested: The Schema class or class name (string)
-        to nest, or ``"self"`` to nest the :class:`Schema` within itself.
+    :param nested: `Schema` instance, class, class name (string), or callable that returns a `Schema` instance.
     :param exclude: A list or tuple of fields to exclude.
     :param only: A list or tuple of fields to marshal. If `None`, all fields are marshalled.
         This parameter takes precedence over ``exclude``.
@@ -462,6 +462,7 @@ class Nested(Field):
     :param kwargs: The same keyword arguments that :class:`Field` receives.
     """
 
+    #: Default error messages.
     default_error_messages = {"type": "Invalid type."}
 
     def __init__(
@@ -486,7 +487,7 @@ class Nested(Field):
             warnings.warn(
                 "Passing 'self' to `Nested` is deprecated. "
                 "Use `Nested(lambda: MySchema(...))` instead.",
-                DeprecationWarning,
+                RemovedInMarshmallow4Warning,
             )
         self.nested = nested
         self.only = only
@@ -521,10 +522,10 @@ class Nested(Field):
                         original = self._schema.only
                     else:  # only=None -> all fields
                         original = self._schema.fields.keys()
-                    self._schema.only = set_class(self.only).intersection(original)
+                    self._schema.only = set_class(self.only) & set_class(original)
                 if self.exclude:
                     original = self._schema.exclude
-                    self._schema.exclude = set_class(self.exclude).union(original)
+                    self._schema.exclude = set_class(self.exclude) | set_class(original)
                 self._schema._init_fields()
             else:
                 if isinstance(nested, type) and issubclass(nested, SchemaABC):
@@ -667,6 +668,7 @@ class List(Field):
         Does not serialize scalar values to single-item lists.
     """
 
+    #: Default error messages.
     default_error_messages = {"invalid": "Not a valid list."}
 
     def __init__(self, cls_or_instance: typing.Union[Field, type], **kwargs):
@@ -735,6 +737,7 @@ class Tuple(Field):
     .. versionadded:: 3.0.0rc4
     """
 
+    #: Default error messages.
     default_error_messages = {"invalid": "Not a valid tuple."}
 
     def __init__(self, tuple_fields, *args, **kwargs):
@@ -804,6 +807,7 @@ class String(Field):
     :param kwargs: The same keyword arguments that :class:`Field` receives.
     """
 
+    #: Default error messages.
     default_error_messages = {
         "invalid": "Not a valid string.",
         "invalid_utf8": "Not a valid utf-8 string.",
@@ -826,6 +830,7 @@ class String(Field):
 class UUID(String):
     """A UUID field."""
 
+    #: Default error messages.
     default_error_messages = {"invalid_uuid": "Not a valid UUID."}
 
     def _validated(self, value) -> typing.Optional[uuid.UUID]:
@@ -855,6 +860,7 @@ class Number(Field):
 
     num_type = float  # type: typing.Type
 
+    #: Default error messages.
     default_error_messages = {
         "invalid": "Not a valid number.",
         "too_large": "Number too large.",
@@ -907,6 +913,8 @@ class Integer(Number):
     """
 
     num_type = int
+
+    #: Default error messages.
     default_error_messages = {"invalid": "Not a valid integer."}
 
     def __init__(self, *, strict: bool = False, **kwargs):
@@ -934,6 +942,8 @@ class Float(Number):
     """
 
     num_type = float
+
+    #: Default error messages.
     default_error_messages = {
         "special": "Special numeric values (nan or infinity) are not permitted."
     }
@@ -989,6 +999,7 @@ class Decimal(Number):
 
     num_type = decimal.Decimal
 
+    #: Default error messages.
     default_error_messages = {
         "special": "Special numeric values (nan or infinity) are not permitted."
     }
@@ -1085,6 +1096,7 @@ class Boolean(Field):
         False,
     }
 
+    #: Default error messages.
     default_error_messages = {"invalid": "Not a valid boolean."}
 
     def __init__(
@@ -1154,6 +1166,7 @@ class DateTime(Field):
 
     SCHEMA_OPTS_VAR_NAME = "datetimeformat"
 
+    #: Default error messages.
     default_error_messages = {
         "invalid": "Not a valid {obj_type}.",
         "invalid_awareness": "Not a valid {awareness} {obj_type}.",
@@ -1281,6 +1294,7 @@ class Time(Field):
     :param kwargs: The same keyword arguments that :class:`Field` receives.
     """
 
+    #: Default error messages.
     default_error_messages = {
         "invalid": "Not a valid time.",
         "format": '"{input}" cannot be formatted as a time.',
@@ -1312,6 +1326,7 @@ class Date(DateTime):
     :param kwargs: The same keyword arguments that :class:`Field` receives.
     """
 
+    #: Default error messages.
     default_error_messages = {
         "invalid": "Not a valid date.",
         "format": '"{input}" cannot be formatted as a date.',
@@ -1355,6 +1370,7 @@ class TimeDelta(Field):
     HOURS = "hours"
     WEEKS = "weeks"
 
+    #: Default error messages.
     default_error_messages = {
         "invalid": "Not a valid period of time.",
         "format": "{input!r} cannot be formatted as a timedelta.",
@@ -1416,6 +1432,8 @@ class Mapping(Field):
     """
 
     mapping_type = dict
+
+    #: Default error messages.
     default_error_messages = {"invalid": "Not a valid mapping type."}
 
     def __init__(
@@ -1560,6 +1578,7 @@ class Url(String):
     :param kwargs: The same keyword arguments that :class:`String` receives.
     """
 
+    #: Default error messages.
     default_error_messages = {"invalid": "Not a valid URL."}
 
     def __init__(
@@ -1592,6 +1611,7 @@ class Email(String):
     :param kwargs: The same keyword arguments that :class:`String` receives.
     """
 
+    #: Default error messages.
     default_error_messages = {"invalid": "Not a valid email address."}
 
     def __init__(self, *args, **kwargs):
